# cflib: Crazyflie Python library [![CI](https://github.com/bitcraze/crazyflie-lib-python/workflows/CI/badge.svg)](https://github.com/bitcraze/crazyflie-lib-python/actions)

`cflib` is a Python library for communicating with and controlling Crazyflie quadcopters, 
including the Crazyflie 2.1(+), Crazyflie 2.1 Brushless, and 
Crazyflie Bolt. This library provides a Python API for direct programmatic control 
through Python scripts, and is also used as the backend communication layer for 
applications like [`cfclient`](https://www.github.com/bitcraze/crazyflie-clients-python).

See [below](#platform-notes) for platform specific instruction.
For more info see our [documentation](https://www.bitcraze.io/documentation/repository/crazyflie-lib-python/master/).

## Installation
See the [installation instructions](docs/installation/install.md) in the github docs folder.

## Official Documentation

Check out the [Bitcraze crazyflie-lib-python documentation](https://www.bitcraze.io/documentation/repository/crazyflie-lib-python/master/) on our website.

## Contribute
Go to the [contribute page](https://www.bitcraze.io/contribute/) on our website to learn more.

### Test code for contribution
Run the automated build locally to test your code

	python3 tools/build/build
